==> eiffelstudio-18.11.10.2592.tar: F_code/C3/po148.c <==
/*
 * Code for class PO_FILE_HEADERS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po148.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_HEADERS}.make */
void F187_2315 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = RTMS_EX_H("",0,0);
	tr1 = F1025_7985(tr1);
	tr2 = RTMS_EX_H("",0,0);
	F186_2310(Current, tr1, tr2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,762,0xFF01,1033,0xFF01,1033,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F763_5414(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_HEADERS}.add_header */
void F187_2319 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,tr2);
	RTLR(4,arg1);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr2 = F1025_7986(RTCW(arg2));
	tr3 = F1025_7986(RTCW(arg1));
	F763_5460(RTCW(tr1), tr2, tr3);
	RTLE;
}

/* {PO_FILE_HEADERS}.to_string */
EIF_REFERENCE F187_2321 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R4040[Dtype(tr1)-752])(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	F763_5453(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F753_5259(RTCW(tr1));
	tr1 = RTLNS(eif_new_type(1033, 0x01).id, 1033, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1025_7926(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	for (;;) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tb1 = F763_5448(RTCW(tr1));
		if (tb1) break;
		F1034_8360(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F763_5426(RTCW(tr1));
		F1034_8335(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H(": ",2,14880);
		tr1 = F1025_7985(tr1);
		F1034_8332(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F763_5425(RTCW(tr1));
		F1034_8335(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H("\\n",2,23662);
		tr1 = F1025_7985(tr1);
		F1034_8332(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr2 = F1_14(loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4036[Dtype(tr1)-592])(RTCW(tr1), tr2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		F763_5454(RTCW(tr1));
	}
	RTLE;
	return (EIF_REFERENCE) F186_2313(Current);
}

/* {PO_FILE_HEADERS}.headers */
EIF_REFERENCE F187_2322 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


void EIF_Minit148 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C3/po148.c <==
/*
 * Code for class PO_FILE_HEADERS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po148.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_HEADERS}.make */
void F187_2324 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = RTMS_EX_H("",0,0);
	tr1 = F1025_8015(tr1);
	tr2 = RTMS_EX_H("",0,0);
	F186_2319(Current, tr1, tr2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,762,0xFF01,1033,0xFF01,1033,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F763_5425(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_HEADERS}.add_header */
void F187_2328 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,tr2);
	RTLR(4,arg1);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr2 = F1025_8016(RTCW(arg2));
	tr3 = F1025_8016(RTCW(arg1));
	F763_5471(RTCW(tr1), tr2, tr3);
	RTLE;
}

/* {PO_FILE_HEADERS}.to_string */
EIF_REFERENCE F187_2330 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R4049[Dtype(RTCW(tr1))-752])(tr1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	F763_5464(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F753_5270(RTCW(tr1));
	loc1 = RTLNS(eif_new_type(1033, 0x01).id, 1033, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1025_7956(RTCW(loc1));
	for (;;) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tb1 = F763_5459(RTCW(tr1));
		if (tb1) break;
		F1034_8390(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F763_5437(RTCW(tr1));
		F1034_8365(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H(": ",2,14880);
		tr1 = F1025_8015(tr1);
		F1034_8362(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr1 = F763_5436(RTCW(tr1));
		F1034_8365(RTCW(loc1), tr1);
		tr1 = RTMS_EX_H("\\n",2,23662);
		tr1 = F1025_8015(tr1);
		F1034_8362(RTCW(loc1), tr1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr2 = F1_14(loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4045[Dtype(RTCW(tr1))-752])(tr1, tr2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		F763_5465(RTCW(tr1));
	}
	RTLE;
	return (EIF_REFERENCE) F186_2322(Current);
}

void EIF_Minit148 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
